/******************************************************************************
*                                                                             *
*                            Module specification                             *
*                                                                             *
*                                Copyright by                                 *
*                                                                             *
*                              Azoteq (Pty) Ltd                               *
*                          Republic of South Africa                           *
*                                                                             *
*                           Tel: +27(0)21 863 0033                            *
*                          E-mail: info@azoteq.com                            *
*                                                                             *
*******************************************************************************
Name             :  includes.h
Description      :  Function definitions for IQS316 SPI firmware library
*******************************************************************************/

#include "IQS316.h"
#include "p18f4550.h"
#include "stdint.h"

#define IQS316_ADDR         0x74

#define RDY                 PORTAbits.RA0
#define SLAVE_SELECT        PORTAbits.RA1

struct tIQS316 {
    unsigned char prox_detected;
    unsigned char prox4_11;
    unsigned char prox12_19;
    unsigned char touch4_11;
    unsigned char touch12_19;
};

// IQS316.c prototypes
void IQS316_Settings(void);
void IQS316_Refresh_Data(void);
void IQS316_Process_Data(void);

void IQS316_Read(uint8_t ui8Address, uint8_t *ui8Data, uint8_t ui8Length);
void IQS316_ReadCurrentAddress(uint8_t *ui8Data, uint8_t ui8Length);
void IQS316_Write(uint8_t ui8Address, uint8_t *ui8Data, uint8_t ui8Length);
void IQS316_End_Comms_Window(void);
void Comms_Error(void);

// lower level PIC18F4550.c prototypes
void init(void);
void Comms_init(void);
uint8_t CommsIQS316_RxTx(uint8_t ui8SendData);
void DelayMS(uint8_t ui8Milliseconds);

// =============================================================================
// =========== PURELY FOR DEBUGGING - not part of library ======================

#define LED1                (uint8_t)0x01        // PD0
#define LED2                (uint8_t)0x02        // PD1
#define LED3                (uint8_t)0x04        // PD2
#define LED4                (uint8_t)0x08        // PD3

#define SET_LED              0x00
#define CLEAR_LED            0x01

#define DEBUG1                (uint8_t)0x40        // PD6
#define DEBUG2                (uint8_t)0x80        // PD7

#define SET_IO              0x00
#define CLEAR_IO            0x01
